@@ -1,8 +1,8 @@
 
 # Function that performs a number of machine-learning methods
-# of classification used in computational stylistics: Delta (Burrows, 2002), 
-# k-Nearest Neighbors classification, Support Vectors Machines, Naive Bayes, 
-# and Nearest Shrunken Centroids (Jockers and Witten, 2010). Most of the options 
+# of classification used in computational stylistics: Delta (Burrows, 2002),
+# k-Nearest Neighbors classification, Support Vectors Machines, Naive Bayes,
+# and Nearest Shrunken Centroids (Jockers and Witten, 2010). Most of the options
 # are derived from the 'stylo' function.
 
 classify <-
@@ -11,7 +11,7 @@ function(gui = TRUE,
          test.frequencies = NULL,
          training.corpus = NULL,
          test.corpus = NULL,
-         features = NULL, 
+         features = NULL,
          path = NULL,
          training.corpus.dir = "primary_set",
          test.corpus.dir = "secondary_set", ...) {
@@ -54,8 +54,6 @@ if(is.character(test.corpus.dir) == FALSE | nchar(test.corpus.dir) == 0) {
   test.corpus.dir = "secondary_set"
 }
 
-
-
 # loading the default settings as defined in the following function
 # (it absorbes the arguments passed from command-line)
 variables = stylo.default.settings(...)
@@ -68,8 +66,8 @@ variables = stylo.default.settings(...)
 if (gui == TRUE) {
       # first, checking if the GUI can be displayed
       # (the conditional expression is stolen form the generic function "menu")
-      if (.Platform$OS.type == "windows" || .Platform$GUI == 
-            "AQUA" || (capabilities("tcltk") && capabilities("X11") && 
+      if (.Platform$OS.type == "windows" || .Platform$GUI ==
+            "AQUA" || (capabilities("tcltk") && capabilities("X11") &&
             suppressWarnings(tcltk::.TkUp))) {
         variables = gui.classify(...)
       } else {
@@ -178,16 +176,16 @@ show.features = variables$show.features
 # #############################################################################
 
 
-# Given a language option ("English", "Polish", "Latin" etc., as described 
+# Given a language option ("English", "Polish", "Latin" etc., as described
 # above), this procedure selects one of the lists of pronouns
-# If no language was chosen (or if a desired language is not supported, or if 
-# there was a spelling mistake), then the variable will be set to "English". 
+# If no language was chosen (or if a desired language is not supported, or if
+# there was a spelling mistake), then the variable will be set to "English".
 
 pronouns = stylo.pronouns(language=corpus.lang)
 
 
 # Since it it not so easy to perform, say, 17.9 iterations, or analyze
-# 543.3 words, the code below justifies all numerical variables, to prevent 
+# 543.3 words, the code below justifies all numerical variables, to prevent
 # you from your stupid jokes with funny settings. (OK, it is still
 # possible to crash the script but we will not give you a hint)
   mfw.min = round(mfw.min)
@@ -210,9 +208,9 @@ if(number.of.candidates < 1) {
 ###############################################################################
 # Backward compatibility: if "use.existing.freq.tables" is switched on, then
 # two files with frequency tables will be used, provided that they do exist
-  if(use.existing.freq.tables == TRUE 
+  if(use.existing.freq.tables == TRUE
                       & file.exists("freq_table_primary_set.txt") == TRUE
-                      & file.exists("freq_table_secondary_set.txt") == TRUE ) { 
+                      & file.exists("freq_table_secondary_set.txt") == TRUE ) {
     training.frequencies = "freq_table_primary_set.txt"
     test.frequencies = "freq_table_secondary_set.txt"
   } else {
@@ -220,7 +218,7 @@ if(number.of.candidates < 1) {
   }
 # Backward compatibility: if "use.existing.wordlist" is switched on, then
 # the file "wordlist.txt" will be used, provided that it does exist
-  if(use.existing.wordlist == TRUE & file.exists("wordlist.txt") == TRUE ) { 
+  if(use.existing.wordlist == TRUE & file.exists("wordlist.txt") == TRUE ) {
     features = "wordlist.txt"
   } else {
     use.existing.wordlist = FALSE
@@ -249,7 +247,7 @@ if(number.of.candidates < 1) {
 # the module for loading a corpus from text files;
 # it can be omitted if the frequency table for
 # both primary and secondary sets already exist
-# (then "use.existing.freq.tables" should be set 
+# (then "use.existing.freq.tables" should be set
 # to TRUE in the preamble of the script/GUI)
 # #################################################
 #
@@ -282,8 +280,8 @@ features.exist = FALSE
   # presumably, this is a file name where a list of words is stored
   if(length(features) == 1) {
     # to prevent using non-letter characters (e.g. integers)
-    features = as.character(features) 
-      # does the file exist? 
+    features = as.character(features)
+      # does the file exist?
       if(file.exists(features) == TRUE) {
         # file with a vector of features will be loaded
         message("\n", "reading a custom set of features from a file...")
@@ -300,7 +298,7 @@ features.exist = FALSE
       }
     # selecting the above vector as a valid set of features
     features.exist = TRUE
-  } 
+  }
 ###############################################################################
 
 
@@ -355,7 +353,7 @@ for(iteration in 1:2) {
   # presumably, this is a file name where a table is stored
   if(length(frequencies) == 1) {
     # to prevent using non-letter characters (e.g. integers)
-    frequencies = as.character(frequencies) 
+    frequencies = as.character(frequencies)
       # does the file exist?
       if(file.exists(frequencies) == TRUE) {
         # file with frequencies will be loaded
@@ -368,7 +366,7 @@ for(iteration in 1:2) {
       }
     # selecting the above matrix as a valid corpus
     corpus.exists = TRUE
-  } 
+  }
 
 
 
@@ -421,19 +419,19 @@ for(iteration in 1:2) {
   }
 
 # attempts at loading the training set and the test set: the loop returns here
-} 
+}
 
 # Two iterations completed, another sanity check should be applied
   # First, let's check if the I set was loaded
   if(!exists("freq.I.set.0.culling") & exists("freq.II.set.0.culling")) {
-    message("Training set is missing, though.")  
-    message("Trying to build both tables from scratch.") 
+    message("Training set is missing, though.")
+    message("Trying to build both tables from scratch.")
     corpus.exists = FALSE
   }
   # Secondly, let's check the II set
   if(exists("freq.I.set.0.culling") & !exists("freq.II.set.0.culling")) {
-    message("Test set is missing, though.")  
-    message("Trying to build both tables from scratch.") 
+    message("Test set is missing, though.")
+    message("Trying to build both tables from scratch.")
     corpus.exists = FALSE
   }
 ###############################################################################
@@ -441,8 +439,8 @@ for(iteration in 1:2) {
 
 
 
-# If the tables with frequencies could not loaded so far (for any reason), 
-# try to load an external corpus (R object) passed as an argument 
+# If the tables with frequencies could not loaded so far (for any reason),
+# try to load an external corpus (R object) passed as an argument
 
 ###############################################################################
 # Checking if the argument "training.corpus" and/or "test.corpus" has been used
@@ -476,7 +474,7 @@ for(iteration in 1:2) {
         message("The samples (elements of the list) should have their names.")
         message("Alternatively, try to build your corpus from text files (default).\n")
         stop("Wrong corpus format")
-      } 
+      }
   }
 
   # 1st iteration: setting the matrix containing the training set (if applicable)
@@ -488,12 +486,12 @@ for(iteration in 1:2) {
     corpus.of.secondary.set = parsed.corpus
   }
 # attempts at loading the training set and the test set: the loop returns here
-} 
+}
 
 # Two iterations completed, another sanity check should be applied
 if(corpus.exists == FALSE) {
     if(length(corpus.of.primary.set) >1 & length(corpus.of.secondary.set) >1 ) {
-      message("Two subcorpora loaded successfully.")  
+      message("Two subcorpora loaded successfully.")
       corpus.exists = TRUE
     } else {
       message("The subcorpora will be loaded from text files...")
@@ -514,22 +512,30 @@ if(corpus.exists == FALSE) {
 
 if(corpus.exists == FALSE) {
 
-  # Retrieving the names of samples
-  #
-  filenames.primary.set = list.files(training.corpus.dir)
-  filenames.secondary.set = list.files(test.corpus.dir)
-
   # Checking whether required files and subdirectories exist
+  # First check: allow user to choose a suitable folder via GUI
   if(file.exists(training.corpus.dir) == FALSE | file.exists(test.corpus.dir) == FALSE) {
-    message("\n\n!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n",
-            "Working directory should contain two subdirectories: 
-            \"", training.corpus.dir, "\" and \"", test.corpus.dir, "\"\n",
-            "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n")
+    selected.path = tk_choose.dir(caption = "Select your working directory. It should two subdirectories called *primary_set* and *secondary_set*")
+    setwd(selected.path)
+  }
+  
+  # If the user failed to provide a suitable folder at this point, abort.
+  if(file.exists(training.corpus.dir) == FALSE | file.exists(test.corpus.dir) == FALSE) {
+    message("\n\n", "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n",
+            "Working directory should contain two subdirectories:
+        \"", training.corpus.dir, "\" and \"", test.corpus.dir, "\"\n",
+            "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n", sep = "")
     # back to the original working directory
     setwd(original.path)
     # error message
     stop("corpus prepared incorrectly")
   }
+  
+  # Retrieving the names of samples
+  #
+  filenames.primary.set = list.files(training.corpus.dir)
+  filenames.secondary.set = list.files(test.corpus.dir)
+  
   # Checking if the subdirectories contain any stuff
   if(length(filenames.primary.set) <2 | length(filenames.secondary.set) <2) {
     message("\n\n!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n",
@@ -553,7 +559,7 @@ if(corpus.exists == FALSE) {
                          sample.size = sample.size,
                          sampling = sampling,
                          sampling.with.replacement = sampling.with.replacement,
-                         sample.overlap = sample.overlap, 
+                         sample.overlap = sample.overlap,
                          number.of.samples = number.of.samples,
                          features = analyzed.features,
                          ngram.size = ngram.size)
@@ -569,7 +575,7 @@ if(corpus.exists == FALSE) {
                          sample.size = sample.size,
                          sampling = sampling,
                          sampling.with.replacement = sampling.with.replacement,
-                         sample.overlap = sample.overlap, 
+                         sample.overlap = sample.overlap,
                          number.of.samples = number.of.samples,
                          features = analyzed.features,
                          ngram.size = ngram.size)
@@ -597,16 +603,16 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
     stop("corpus error")
   }
 
-  # If an external vector of features (usually: the most frequent words) has not 
-  # been specified (cf. the argument "features"), then we need a list of the most 
-  # frequent words (or n-grams, or anything else) used in the current corpus, 
-  # in descending order, without frequencies (just a list of words/features). 
+  # If an external vector of features (usually: the most frequent words) has not
+  # been specified (cf. the argument "features"), then we need a list of the most
+  # frequent words (or n-grams, or anything else) used in the current corpus,
+  # in descending order, without frequencies (just a list of words/features).
   if (features.exist == TRUE) {
     message("")
     message("using an existing wordlist (vector of features)...")
     mfw.list.of.all = features
   } else {
-    # Extracting all the words (features) used in the texts of primary set 
+    # Extracting all the words (features) used in the texts of primary set
     # (or both if "Z-scores all" is set to TRUE)
     wordlist.of.primary.set = c()
     message("")
@@ -637,7 +643,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
         # otherwise, create an empty vector
         wordlist.of.secondary.set = c()
       }
-      
+
     # Preparing a sorted frequency list of the whole primary set (or both sets).
     # short message
     message(" ")
@@ -657,7 +663,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
     # some comments into the file containing wordlist
     cat("# This file contains the words that were used for building the table",
       "# of frequencies. It can be also used for the next tasks, and for this",
-      "# purpose it can be manually revised, edited, deleted, culled, etc.", 
+      "# purpose it can be manually revised, edited, deleted, culled, etc.",
       "# You can either delete unwanted words, or mark them with \"#\"",
       "# -----------------------------------------------------------------------",
       "", file = "wordlist.txt", sep = "\n")
@@ -670,7 +676,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
       }
   # writing the stuff
   cat(data.to.be.saved, file = "wordlist.txt", sep = "\n", append = TRUE)
-  
+
   }   # <----- conditional expr. if(features.exist == TRUE) terminates here
 
 
@@ -684,7 +690,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
 	  if (file.exists("sample_dump_primary_set")){
 		# a dump-dir seems to have been created during a previous run
 		# tmp delete the dump-dir to remove all of its previous contents
-		unlink("sample_dump_primary_set", recursive = TRUE) 
+		unlink("sample_dump_primary_set", recursive = TRUE)
 	  }
 	# (re)create the dump-dir
 	dir.create("sample_dump_primary_set")
@@ -700,7 +706,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
 	  if (file.exists("sample_dump_secondary_set")){
 		# a dump-dir seems to have been created during a previous run
 		# tmp delete the dump-dir to remove all of its previous contents
-		unlink("sample_dump_secondary_set", recursive = TRUE) 
+		unlink("sample_dump_secondary_set", recursive = TRUE)
 	  }
 	# (re)create the dump-dir
 	dir.create("sample_dump_secondary_set")
@@ -736,7 +742,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
 
   # writing the frequency tables to text files (they can be re-used!)
   # first, the training set
-      # checking if any re-encoding is needed 
+      # checking if any re-encoding is needed
       if(encoding == "native.enc") {
         data.to.be.saved = t(freq.I.set.0.culling)
       } else {
@@ -748,7 +754,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
   write.table(data.to.be.saved, file = "freq_table_primary_set.txt")
 
   # now, the test set
-      # checking if any re-encoding is needed 
+      # checking if any re-encoding is needed
       if(encoding == "native.enc") {
         data.to.be.saved = t(freq.II.set.0.culling)
       } else {
@@ -759,7 +765,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
   # writing the stuff
   write.table(data.to.be.saved, file = "freq_table_secondary_set.txt")
 
-  
+
 }
 ###############################################################################
 
@@ -775,7 +781,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
 
 # Finally, we want to save some variable values for later use
 cat("", file = "classify_config.txt", append = FALSE)
-var.name <- function(x) { 
+var.name <- function(x) {
       if(is.character(x) == TRUE) {
       cat(paste(deparse(substitute(x)), " = \"", x, "\"", sep = ""), file = "classify_config.txt", sep = "\n", append = TRUE)
         } else {
@@ -819,10 +825,10 @@ var.name <- function(x) {
  var.name(save.distance.tables)
  var.name(save.analyzed.features)
  var.name(save.analyzed.freqs)
- 
 
- 
- 
+
+
+
 # #################################################
 
 
@@ -886,7 +892,7 @@ perfect.guessing = length(authors.II.set[authors.II.set %in% authors.I.set])
 # if max value is LOWER than min value, make them equal
   if(culling.max < culling.min) {
   culling.max = culling.min
-  }  
+  }
 # avoiding infinite loops
   if(culling.incr <= 1) {
   culling.incr = 10
@@ -901,44 +907,44 @@ for(j in (culling.min/culling.incr):(culling.max/culling.incr)) {
 
         current.culling = j * culling.incr
 
-        
+
         # applying culling
-        # an additional table composed of relative word frequencies 
+        # an additional table composed of relative word frequencies
         # of joint primary and secondary sets
         if(culling.of.all.samples == FALSE) {
                 # applying the function culling to the I set
-                primary.set = perform.culling(freq.I.set.0.culling,  
+                primary.set = perform.culling(freq.I.set.0.culling,
                                              current.culling)
                 # selecting the same variables from the II set
                 secondary.set = freq.II.set.0.culling[,colnames(primary.set)]
         } else {
                 # combining the two sets
-                freq.table.both.sets = rbind(freq.I.set.0.culling, 
+                freq.table.both.sets = rbind(freq.I.set.0.culling,
                                              freq.II.set.0.culling)
                 # applying the culling function to the combined table
-                freq.table.both.sets = perform.culling(freq.table.both.sets, 
+                freq.table.both.sets = perform.culling(freq.table.both.sets,
                                              current.culling)
                 # split the combined table into two sets again
                 primary.set = freq.table.both.sets[rownames(freq.I.set.0.culling),]
                 secondary.set = freq.table.both.sets[rownames(freq.II.set.0.culling),]
         }
 
-        
+
 
         # additionally, deleting pronouns (if applicable)
         if(delete.pronouns == TRUE) {
                 primary.set = delete.stop.words(primary.set, pronouns)
                 secondary.set = delete.stop.words(secondary.set, pronouns)
         }
-        
+
 
         # optionally, deleting stop words
         if(is.vector(stop.words) == TRUE) {
-                primary.set = delete.stop.words(primary.set, stop.words)        
+                primary.set = delete.stop.words(primary.set, stop.words)
                 secondary.set = delete.stop.words(secondary.set, stop.words)
         }
 
-        
+
 
 
 # #################################################
@@ -950,7 +956,7 @@ for(j in (culling.min/culling.incr):(culling.max/culling.incr)) {
 
 # starting the frequency list at frequency rank set in option start.at above
 
-# TO SAY THE TRUTH, IT CAN BE DONE MUCH EARLIER: at the moment when 
+# TO SAY THE TRUTH, IT CAN BE DONE MUCH EARLIER: at the moment when
 # the frequency list for either I set or both sets is produced,
 # it can be cut and used for building freq. tables
 
@@ -989,10 +995,10 @@ message("culling @ ", current.culling, "\t", "available words ",
 
 
 
-                  
 
 
-# an additional table composed of relative word frequencies 
+
+# an additional table composed of relative word frequencies
 # of joint primary and secondary sets
 freq.table.both.sets = rbind(primary.set, secondary.set)
 
@@ -1096,7 +1102,7 @@ message(mfw, " ", appendLF = FALSE)
 
 
 if(tolower(classification.method) == "delta") {
-  classification.results = perform.delta(training.set = primary.set[,1:mfw], 
+  classification.results = perform.delta(training.set = primary.set[,1:mfw],
                                 test.set = secondary.set[,1:mfw],
                                 distance = distance.measure,
                                 z.scores.both.sets = z.scores.of.all.samples)
@@ -1106,27 +1112,27 @@ if(tolower(classification.method) == "delta") {
 
 
 if(tolower(classification.method) == "knn") {
-  classification.results = perform.knn(training.set = primary.set[,1:mfw], 
+  classification.results = perform.knn(training.set = primary.set[,1:mfw],
                                        test.set = secondary.set[,1:mfw],
                                        k.value = k.value)
 }
 
 
 if(tolower(classification.method) == "svm") {
-  classification.results = perform.svm(training.set = primary.set[,1:mfw], 
+  classification.results = perform.svm(training.set = primary.set[,1:mfw],
                                        test.set = secondary.set[,1:mfw])
 }
 
 
 if(tolower(classification.method) == "naivebayes") {
-  classification.results = perform.naivebayes(training.set= primary.set[,1:mfw], 
+  classification.results = perform.naivebayes(training.set= primary.set[,1:mfw],
                                               test.set = secondary.set[,1:mfw])
 }
 
 
 if(tolower(classification.method) == "nsc") {
-  classification.results = perform.nsc(training.set = primary.set[,1:mfw], 
-                                       test.set = secondary.set[,1:mfw], 
+  classification.results = perform.nsc(training.set = primary.set[,1:mfw],
+                                       test.set = secondary.set[,1:mfw],
                                        show.features = show.features)
 }
 
@@ -1141,10 +1147,10 @@ classes.test = gsub("_.*","",rownames(secondary.set))
 # returns the ranking of the most likely candidates as a list
 if(final.ranking.of.candidates == TRUE) {
     cat("\n\n\n", file = outputfile, append = TRUE)
-      misclassified.samples = 
+      misclassified.samples =
                    paste(rownames(secondary.set), "\t-->\t",
                    classification.results)[classes.test!=classification.results]
-      cat(misclassified.samples, file = outputfile, append = TRUE, sep = "\n") 
+      cat(misclassified.samples, file = outputfile, append = TRUE, sep = "\n")
       # temporarily (the results should be made available, eventually)
       rm(misclassified.samples)
 }
@@ -1154,11 +1160,11 @@ if(final.ranking.of.candidates == TRUE) {
 
 # returns the number of correct attributions
 if(how.many.correct.attributions == TRUE) {
-    no.of.correct.attrib = sum(as.numeric(classes.test == 
+    no.of.correct.attrib = sum(as.numeric(classes.test ==
                                  classification.results))
-    total.no.of.correct.attrib = 
+    total.no.of.correct.attrib =
          c(total.no.of.correct.attrib, no.of.correct.attrib)
-    total.no.of.possible.attrib = 
+    total.no.of.possible.attrib =
          c(total.no.of.possible.attrib, perfect.guessing)
     cat("\n", file = outputfile, append = TRUE)
     cat(mfw, " MFW , culled @ ", current.culling, "%,  ",
@@ -1181,7 +1187,7 @@ if(cv.folds > 0) {
 
   message("")
   message("cross-validation...")
- 
+
 
   #bootstrap.output = "bootstrap_output.txt"
   #cleaning the bootstrapfile
@@ -1198,7 +1204,7 @@ if(cv.folds > 0) {
   for(iterations in 1 : cv.folds) {
 
     # an additional table combined of frequencies of set I and II
-    # just for feeding the bootstrap module 
+    # just for feeding the bootstrap module
     freq.table.both.sets.binded = rbind(primary.set[,1:mfw], secondary.set[,1:mfw])
 
 
@@ -1207,11 +1213,11 @@ if(cv.folds > 0) {
     classes.test.set = gsub("_.*", "", rownames(secondary.set))
     names.both.sets = rownames(freq.table.both.sets.binded)
     classes.both.sets = c(classes.training.set, classes.test.set)
-    
+
     training.samples = c()
     test.samples = c()
 
-    
+
       # this looks for classes that were not represented so far in I set
       for(i in names(table(classes.training.set)) ) {
         #
@@ -1219,7 +1225,7 @@ if(cv.folds > 0) {
         no.of.training.samples = sum(as.numeric(classes.training.set == i))
         # determine the class' name, surround the name with word boundary char
         class.name = paste("\\b", i, "\\b", sep = "")
-        # in both sets, identify the positions of current class' samples 
+        # in both sets, identify the positions of current class' samples
         pinpoint.samples = grep(class.name, classes.both.sets)
         # sanity check, just in case
         if(length(pinpoint.samples) > no.of.training.samples) {
@@ -1247,14 +1253,14 @@ if(cv.folds > 0) {
   # establishing the test set
   test.set = freq.table.both.sets.binded[test.samples,]
 
-  
+
  # zscores.training.set = zscores.table.both.sets[training.samples,]
  # zscores.test.set = zscores.table.both.sets[test.samples,]
-    
+
 
   if(tolower(classification.method) == "delta") {
     classification.results = perform.delta(training.set,
-                                   test.set, 
+                                   test.set,
                                    distance = distance.measure,
                                    z.scores.both.sets = z.scores.of.all.samples)
     distance.table = attr(classification.results, "distance.table")
@@ -1266,26 +1272,26 @@ if(cv.folds > 0) {
     classification.results = perform.svm(training.set, test.set)
   }
   if(tolower(classification.method) == "nsc") {
-    classification.results = perform.nsc(training.set, test.set, 
+    classification.results = perform.nsc(training.set, test.set,
                                          show.features = show.features)
   }
   if(tolower(classification.method) == "naivebayes") {
     classification.results = perform.naivebayes(training.set, test.set)
   }
 
-  
-  
+
+
   # retrieving classes of the new training set
   classes.training = gsub("_.*", "", rownames(training.set))
-  
+
   # retrieving classes of the new test set
   classes.test = gsub("_.*", "", rownames(test.set))
 
 
-  
+
     # returns the number of correct attributions
     if(how.many.correct.attributions == TRUE) {
-          no.of.correct.attrib = sum(as.numeric(classes.test == 
+          no.of.correct.attrib = sum(as.numeric(classes.test ==
                                      classification.results))
       # getting the max. number of samples that couold be guessed
       perfect.guessing.cv = sum(as.numeric(classes.test %in% classes.training))
@@ -1302,7 +1308,7 @@ if(cv.folds > 0) {
 
   }
 
-  
+
   cross.validation.results.all = cbind(cross.validation.results.all, cross.validation.results)
   colnames(cross.validation.results.all) = paste(mfw, "@", current.culling, sep="")
 }   # <-- if(cv.folds > 0)
@@ -1407,7 +1413,7 @@ total.no.of.possible.attrib = sum(total.no.of.possible.attrib)
 # information about the current task into the logfile
 cat("\nGeneral attributive success:  ", total.no.of.correct.attrib, " of ",
            total.no.of.possible.attrib, " (",
-           round(total.no.of.correct.attrib/total.no.of.possible.attrib*100, 1), 
+           round(total.no.of.correct.attrib/total.no.of.possible.attrib*100, 1),
            "%)\n", file = outputfile, append = TRUE, sep = "")
 cat("\nMFWs from ", mfw.min, " to ", mfw.max.original,
                   " @ increment ", mfw.incr, "\nCulling from ", culling.min,
@@ -1421,7 +1427,7 @@ cat("\n", file = outputfile, append = TRUE)
 # the same information (about the current task) on screen
 message("\nGeneral attributive success:  ", total.no.of.correct.attrib, " of ",
            total.no.of.possible.attrib, " (",
-           round(total.no.of.correct.attrib/total.no.of.possible.attrib*100,1), 
+           round(total.no.of.correct.attrib/total.no.of.possible.attrib*100,1),
            "%, sd =", round(sd(all.guesses),1),"%)")
 message("\nMFWs from ", mfw.min, " to ", mfw.max.original,
                   " @ increment ", mfw.incr, "\nCulling from ", culling.min,
@@ -1437,8 +1443,8 @@ message("")
 
 # Names of many variables are incredibly unfashionable: they were acceptable
 # in ver. 0.0.1 of the script, which provided just a basic Delta test
-# with no additional options. Since it is quite a lot of work to modernize 
-# the variables' names in the code (and parhaps it is too late now...), 
+# with no additional options. Since it is quite a lot of work to modernize
+# the variables' names in the code (and parhaps it is too late now...),
 # these simple wrappers will rename at least the variables to be exported:
 success.rate = all.guesses
   if(length(success.rate) >1) {
@@ -1526,12 +1532,12 @@ results.classify = list()
 variables.to.save = c("misclassified.samples",
                       "success.rate",
                       "overall.success.rate",
-                      "distance.table", 
+                      "distance.table",
                       "distinctive.features",
                       "features",
                       "features.actually.used",
                       "zscores.both.sets",
-                      "frequencies.both.sets", 
+                      "frequencies.both.sets",
                       "frequencies.training.set",
                       "cross.validation.summary",
                       "frequencies.test.set")
@@ -1565,8 +1571,6 @@ class(results.classify) = "stylo.results"
 # back to the original working directory
 setwd(original.path)
 
-# return the value of the function 
+# return the value of the function
 return(results.classify)
 }
-
-
