@@ -21,12 +21,26 @@ perform.svm = function(training.set,
   # library(e1071)
   #
 
-  # getting the number of features (e.g. MFWs)
-  no.of.cols = length(training.set[1,])
-    
+  # first, sanitizing the type of input data
+  if(length(dim(training.set)) != 2) {
+      stop("train set error: a 2-dimensional table (matrix) is required")
+  }
+  # if a vector (rather than a matrix) was used as a test set, a fake row
+  # will be added; actually, this will be a duplicate of the vector
+  if(is.vector(test.set) == TRUE) {
+      test.set = rbind(test.set, test.set)
+      rownames(test.set) = c("unknown", "unknown-copy")
+      # additionally, duplicating ID of the test classes (if specified)
+      if(length(classes.test.set) == 1) {
+      	  classes.test.set = c(classes.test.set, "unknown-copy")
+      }
+  }
+
+  
+
   # checking if the two sets are of the same size
-  if(length(test.set[1,]) != no.of.cols) {
-          stop("training set and test set should the same number of variables!")
+  if(length(test.set[1,]) != length(training.set[1,])) {
+          stop("training set and test set should have the same number of variables!")
   }
   
   # assigning classes, if not specified
@@ -38,10 +52,15 @@ perform.svm = function(training.set,
   }
   
   #
+  
+  
+  # getting rid of the variables that are not represented in the training set
+  check.columns = colSums(training.set)
+  training.set = training.set[,(check.columns != 0)]
+  test.set = test.set[,(check.columns != 0)]
 
-
-#  classes.training.set = gsub("_.*","",rownames(training.set))
-#  classes.test.set = gsub("_.*","",rownames(test.set))
+  
+  
   classes = c(classes.training.set, classes.test.set)
   input.data = as.data.frame(rbind(training.set,test.set))
   input.data = cbind(classes, input.data)
@@ -130,6 +149,15 @@ perform.svm = function(training.set,
           classification.rankings = rbind(classification.rankings, current.ranking)
   }
   
+  
+  # preparing a confusion table
+  predicted_classes = classification.results
+  actual_classes = classes.test.set
+  confusion.matrix = table(predicted_classes, actual_classes)
+  # getting rid of the classes not represented in the training set (e.g. anonymous samples)
+#  confusion.matrix = confusion.matrix[,rownames(confusion.matrix)]
+
+  
   names(classification.results) = rownames(test.set)
   rownames(classification.rankings) = rownames(test.set)
   rownames(classification.scores) = rownames(test.set)
@@ -139,6 +167,8 @@ perform.svm = function(training.set,
   attr(classification.results, "distance.table") = selected.dist
   attr(classification.results, "rankings") = classification.rankings
   attr(classification.results, "scores") = classification.scores
+  attr(classification.results, "confusion_matrix") = confusion.matrix
+
   
 return(classification.results)
 }
